strings

package
v2.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToLower

func ToLower(s string) string

ToLower converts an ASCII string to lower-case without modifying the input.

func ToUpper

func ToUpper(s string) string

ToUpper converts an ASCII string to upper-case without modifying the input.

func UnsafeToLower

func UnsafeToLower(s string) string

UnsafeToLower converts an ASCII string to lower-case by mutating its backing bytes in-place. This function is unsafe: it breaks string immutability and must only be used when the string is known to reference mutable memory.

func UnsafeToUpper

func UnsafeToUpper(s string) string

UnsafeToUpper converts an ASCII string to upper-case by mutating its backing bytes in-place. This function is unsafe: it breaks string immutability and must only be used when the string is known to reference mutable memory.

Types

This section is empty.

Jump to